.. _spkg_cysignals:

cysignals: Interrupt and signal handling for Cython
===================================================

Description
-----------

Interrupt and signal handling for Cython

License
-------

LGPL version 3 or later


Upstream Contact
----------------

https://github.com/sagemath/cysignals



Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_cython`
- :ref:`spkg_meson_python`

Version Information
-------------------

package-version.txt::

    8504c2687a98f166df902c8a848ca3975ce9552b

pyproject.toml::

    cysignals !=1.12.4; sys_platform == 'win32'
    cysignals >=1.11.2, != 1.12.0

version_requirements.txt::

    cysignals

See https://repology.org/project/cysignals/versions, https://repology.org/project/python:cysignals/versions

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install cysignals\!=1.12.4\;sys_platform==\"win32\" cysignals\>=1.11.2\,\!=1.12.0

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i cysignals

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install cysignals

.. tab:: Gentoo Linux:

   .. CODE-BLOCK:: bash

       $ sudo emerge dev-python/cysignals

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-python-cysignals


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
